@@ -1,10 +1,16 @@
+import asyncio
+import os
+import warnings
+import logging
+import signal
+import sys
 from PuppeteerLibrary.keywords.checkbox import CheckboxKeywords
 from typing import List
 from PuppeteerLibrary.base.ipuppeteer_library import iPuppeteerLibrary
-import asyncio
 from robot.api.deco import not_keyword
 from robot.api import logger
 from robot.libraries.BuiltIn import BuiltIn
+from robot.errors import ExecutionFailed
 from pyppeteer.browser import Browser
 from PuppeteerLibrary.library_context.ilibrary_context import iLibraryContext
 from PuppeteerLibrary.library_context.library_context_factory import LibraryContextFactory
@@ -51,6 +57,20 @@ class PuppeteerLibrary(DynamicCore, iPuppeteerLibrary):
     | link	       | Exact text a link has.	             | ``link:Home page``             |
     | partial link | Partial link text   	             | ``partial link:Home``          |
 
+    == Chain Locator only for Playwright ==
+    Playwright support ``Chaining selectors`` strategy. This allow us to chain following support locator.
+    Selectors can be combined with the ``>>`` token, e.g. selector1 >> selector2 >> selectors3. 
+    When selectors are chained, next one is queried relative to the previous one's result.
+
+    Support chaining locator strategy: css and xpath
+
+    More detail [Chaining selectors](https://playwright.dev/docs/selectors#chaining-selectors)
+
+    Example:
+
+    chain=css=article >> css=.bar > css=.baz >> css=span[attr=value]
+
+
     == Timeout ==
     Timeout will use for Wait.. keywords. By default Puppeteer will use default timeout value if you
     didn't specific in keywords argument.
@@ -92,7 +112,17 @@ class PuppeteerLibrary(DynamicCore, iPuppeteerLibrary):
     library_factory: LibraryContextFactory = None
     library_contexts: dict = {}
 
-    def __init__(self):
+    def __init__(self, disable_python_logging=True):
+        
+        if disable_python_logging:
+            self._disable_python_logging()
+
+        # Support RIDE
+        try:
+            signal.signal(signal.SIGINT, self.terminal_signal_handler)
+        except:
+            print('Warning: Not handle terminal signal')
+
         try:
             self.loop = asyncio.get_event_loop()
         except:
@@ -129,7 +159,9 @@ class PuppeteerLibrary(DynamicCore, iPuppeteerLibrary):
 
     @not_keyword
     def get_library_context_by_name(self, alias: str) -> iLibraryContext:
-        return self.library_contexts[alias]
+        if alias in self.library_contexts:
+            return self.library_contexts[alias]
+        return None
 
     @not_keyword
     def get_all_library_context(self) -> List[iLibraryContext]:
@@ -168,7 +200,8 @@ class PuppeteerLibrary(DynamicCore, iPuppeteerLibrary):
         try:
             return DynamicCore.run_keyword(self, name, args, kwargs)
         except Exception:
-            self.failure_occurred()
+            if name.lower().replace(' ', '_') != 'capture_page_screenshot':
+                self.failure_occurred()
             raise
         finally:
             self._running_keyword = None
@@ -180,6 +213,23 @@ class PuppeteerLibrary(DynamicCore, iPuppeteerLibrary):
             logger.warn("Keyword '%s' could not be run on failure: %s"
                         % (self.run_on_failure_keyword, err))
 
+    def terminal_signal_handler(self, sig, frame):
+        print('You pressed Ctrl+C!')
+        BuiltIn().run_keyword_and_ignore_error('Close Puppeteer')
+        self._stop_execution_gracefully()
+
+    def _disable_python_logging(self):
+        # Force node not throw any unhandled task
+        os.environ['NODE_OPTIONS'] = '--unhandled-rejections=none'
+        warnings.filterwarnings('ignore')
+        logging.getLogger('asyncio').setLevel(logging.ERROR)
+        logging.getLogger('asyncio.coroutines').setLevel(logging.ERROR)
+        logging.disable(logging.CRITICAL)
+        logging.warning('Protocol problem:')
+
+    def _stop_execution_gracefully(self):
+        raise ExecutionFailed('Execution terminated by signal', exit=True)
+
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
