@@ -4,10 +4,6 @@ from PuppeteerLibrary.ikeywords.base_async_keywords import BaseAsyncKeywords
 
 class iBrowserManagementAsync(BaseAsyncKeywords, ABC):
 
-    @abstractmethod
-    async def maximize_browser_window(self, width=1366, height=768):
-        pass
-
     @abstractmethod
     async def go_to(self, url):
         pass
@@ -32,6 +28,24 @@ class iBrowserManagementAsync(BaseAsyncKeywords, ABC):
     async def switch_window(self, locator='MAIN'):
         pass
 
+    ##############################
+    # Trace
+    ##############################
+    @abstractmethod
+    async def start_tracing(self):
+        pass
+
+    @abstractmethod
+    async def stop_tracing(self, path=None):
+        pass
+
+    ##############################
+    # Page
+    ##############################
+    @abstractmethod
+    async def set_view_port_size(self, width, height):
+        pass
+
     ##############################
     # iFrame
     ##############################
@@ -46,5 +60,14 @@ class iBrowserManagementAsync(BaseAsyncKeywords, ABC):
     ##############################
     # Cookies
     ##############################
+    async def get_cookie(self, name: str):
+        pass
+
+    async def get_cookies(self):
+        pass
+    
+    async def add_cookie(self, name: str, value: str):
+        pass
+
     async def delete_all_cookies(self):
         pass
