@@ -16,6 +16,14 @@ class iDropdownAsync(BaseAsyncKeywords, ABC):
     async def get_selected_list_labels(self, locator: str) -> str:
         pass
 
+    @abstractmethod
+    async def get_list_labels(self, locator: str) -> str:
+        pass
+
     @abstractmethod
     async def get_selected_list_values(self, locator: str) -> str:
-        pass
\ No newline at end of file
+        pass
+
+    @abstractmethod
+    async def get_list_values(self, locator: str) -> str:
+        pass
