@@ -1,6 +1,7 @@
 from PuppeteerLibrary.base.librarycomponent import LibraryComponent
 from PuppeteerLibrary.base.robotlibcore import keyword
 from PuppeteerLibrary.ikeywords.ibrowsermanagement_async import iBrowserManagementAsync
+from robot.libraries.BuiltIn import BuiltIn
 
 
 class BrowserManagementKeywords(LibraryComponent):
@@ -12,15 +13,17 @@ class BrowserManagementKeywords(LibraryComponent):
         return self.ctx.get_current_library_context().get_async_keyword_group(type(self).__name__)
 
     @keyword
-    def open_browser(self, url, browser="chrome", alias=None, options=None):
+    def open_browser(self, url, browser="chrome", alias=None, options={}):
         """Opens a new browser instance to the specific ``url``.
 
         The ``browser`` argument specifies which browser to use.
 
-        |    = Browser =         |    = Name(s) =   |
-        | Google Chrome          | chrome           |
-        | Webkit (Safari engine) | webkit           |
-        | Firefox                | firefox          |
+        |    = Browser =           |    = Name(s) =   |    = Engine =   |
+        | Google Chrome Default    | chrome           | Playwright      |
+        | Google Chrome Playwright | pwchrome         | Playwright      |
+        | Google Chrome Puppeteer  | ptchrome         | Puppeteer       |
+        | Webkit (Safari engine)   | webkit           | Playwright      |
+        | Firefox                  | firefox          | Playwright      |
 
         The ``options`` argument as a dictionary
 
@@ -30,13 +33,24 @@ class BrowserManagementKeywords(LibraryComponent):
         | height             | default 768            |
         | emulate            | iPhone 11              |
 
+        **Other options**
+        pwchrome, webkit and firefox please visit: https://playwright.dev/python/docs/api/class-browser?_highlight=new_page#browsernew_pagekwargs
+        chrome please visit: https://pptr.dev/#?product=Puppeteer&version=v8.0.0&show=api-puppeteerlaunchoptions
+
         Example:
 
         | &{options} =   | create dictionary                             | headless=${False}  |
         | `Open browser` | https://www.w3schools.com/html/html_forms.asp | options=${options} |
 
         """
-        library_context = self.ctx.create_library_context(alias, browser)
+        if options is None:
+            options = {}
+            
+        self.info(url)
+        library_context = self.ctx.get_library_context_by_name(alias)
+        if library_context is None:
+            library_context = self.ctx.create_library_context(alias, browser)
+        self.loop.run_until_complete(self.ctx.set_current_library_context(alias))
         self.loop.run_until_complete(library_context.start_server(options))
         self.loop.run_until_complete(library_context.create_new_page(options))
         self.loop.run_until_complete(self.get_async_keyword_group().go_to(url))
@@ -66,30 +80,20 @@ class BrowserManagementKeywords(LibraryComponent):
 
     @keyword
     def close_puppeteer(self):
-        library_contexts_dict =  self.ctx.get_all_library_context_dict()
+        library_contexts_dict = self.ctx.get_all_library_context_dict()
         for key in list(library_contexts_dict.keys()):
             self.loop.run_until_complete(library_contexts_dict[key].stop_server())
             self.ctx.remove_library_context(key)
 
-    @keyword
-    def maximize_browser_window(self, width=1366, height=768):
-        """Maximize view port not actual browser and set default size to 1366 x 768
-        """
-        self.info(('width: ' + str(width) + '\n' +
-                   'height: ' + str(height)))
-        self.loop.run_until_complete(self.get_async_keyword_group().maximize_browser_window(width, height))
-
     @keyword
     def get_title(self):
         """Get page title"""
-        async def get_title_async():
-            return await self.ctx.get_current_page().title()
-        return self.loop.run_until_complete(get_title_async())
+        return self.loop.run_until_complete(self.ctx.get_current_library_context().get_current_page().title())
 
     @keyword
     def get_location(self):
         """Get page location"""
-        return self.ctx.get_current_page().url
+        return self.ctx.get_current_library_context().get_current_page().get_page().url
 
     @keyword
     def go_back(self):
@@ -99,6 +103,7 @@ class BrowserManagementKeywords(LibraryComponent):
     @keyword
     def go_to(self, url):
         """Navigates the current page to the ``url``"""
+        self.info(url)
         self.loop.run_until_complete(self.get_async_keyword_group().go_to(url))
 
     @keyword
@@ -157,6 +162,37 @@ class BrowserManagementKeywords(LibraryComponent):
         """
         return self.loop.run_until_complete(self.get_async_keyword_group().enable_emulate_mode_async(emulate_name))
 
+    ##############################
+    # Trace
+    ##############################
+    @keyword
+    def start_tracing(self):
+        """Create trace log file
+
+        # View the trace by running following command
+
+        playwright show-trace trace.zip
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().start_tracing())
+
+    @keyword
+    def stop_tracing(self, path=None):
+        """Stop trace and generate the trace file.
+
+        Default will be ``traces/<testcasename>.zip``
+        """
+        if path is None:
+            test_name = BuiltIn().get_variable_value("${TEST_NAME}")
+            path = 'traces/'+test_name+'.zip'
+        return self.loop.run_until_complete(self.get_async_keyword_group().stop_tracing(path))
+
+    ##############################
+    # Page
+    ##############################
+    @keyword
+    def set_view_port_size(self, width, height):
+        return self.loop.run_until_complete(self.get_async_keyword_group().set_view_port_size(width, height))
+
     ##############################
     # iFrame
     ##############################
@@ -171,6 +207,28 @@ class BrowserManagementKeywords(LibraryComponent):
     ##############################
     # Cookies
     ##############################
+    @keyword
+    def get_cookie(self, name):
+        """ Get cookie by name
+
+            Returns Cookie value
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().get_cookie(name))
+
+    @keyword
+    def get_cookies(self):
+        """ Get all cookies
+
+            Returns Dictionary for all cookies of the current page.
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().get_cookies())
+
+    @keyword
+    def add_cookie(self, name, value):
+        """ Add cookie
+        """
+        return self.loop.run_until_complete(self.get_async_keyword_group().add_cookie(name, value))
+
     @keyword
     def delete_all_cookies(self):
         """ Deletes all cookies.
