@@ -15,12 +15,14 @@ class MouseEventKeywords(LibraryComponent):
     def mouse_over(self, locator):
         """Mouse over the element.
         """
+        self.info(f"Mouse over '{locator}'.")
         return self.loop.run_until_complete(self.get_async_keyword_group().mouse_over(locator))
 
     @keyword
     def mouse_down(self, locator):
         """Mouse down on the element.
         """
+        self.info(f"Mouse down '{locator}'.")
         return self.loop.run_until_complete(self.get_async_keyword_group().mouse_down(locator))
 
     @keyword
@@ -32,5 +34,17 @@ class MouseEventKeywords(LibraryComponent):
     @keyword
     def mouse_move(self, x, y):
         """Move mouse to position x, y.
+
+        *Limitation* Drag event only support for css / id locator. Not support for xpath locator or chain locator.
         """
+        self.info(f"Mouse move to x: '{x}', y: '{y}'.")
         return self.loop.run_until_complete(self.get_async_keyword_group().mouse_move(x, y))
+
+    @keyword
+    def drag_and_drop(self, src_locator, desc_locator):
+        """Drag item form sort locator to destination locator
+
+        *Limitation* Drag event only support for css / id locator. Not support for xpath locator or chain locator.
+        """
+        self.info(f"Draf from '{src_locator}' to '{desc_locator}'.")
+        return self.loop.run_until_complete(self.get_async_keyword_group().drag_and_drop(src_locator, desc_locator))
