@@ -1,17 +1,20 @@
-from PuppeteerLibrary.custom_elements.base_page import BasePage
+import os
 from abc import ABC, abstractmethod
+from PuppeteerLibrary.custom_elements.base_page import BasePage
 
 
 class iLibraryContext(ABC):
 
     browser_type: str = None
+    screenshot_path: str = None
     timeout: int = 30
 
     def __init__(self, browser_type: str):
         self.browser_type = browser_type
+        self.screenshot_path = os.curdir
     
     @abstractmethod
-    async def start_server(self, options: dict=None):
+    async def start_server(self, options: dict={}):
         pass
 
     @abstractmethod
@@ -23,7 +26,11 @@ class iLibraryContext(ABC):
         pass
 
     @abstractmethod
-    async def create_new_page(self, options: dict=None) -> BasePage:
+    def set_default_timeout(self, timeout):
+        pass
+
+    @abstractmethod
+    async def create_new_page(self, options: dict={}) -> BasePage:
         pass
 
     @abstractmethod
@@ -53,3 +60,11 @@ class iLibraryContext(ABC):
     @abstractmethod
     def get_async_keyword_group(self, keyword_group_name: str):
         pass
+
+    def set_screenshot_path(self, path: str):
+        self.screenshot_path = path
+        if not os.path.exists(self.screenshot_path):
+            os.makedirs(self.screenshot_path)
+
+    def get_screenshot_path(self):
+        return self.screenshot_path
