@@ -1,6 +1,7 @@
 from PuppeteerLibrary.utils.coverter import str2bool
 from robot.libraries.BuiltIn import BuiltIn
 from PuppeteerLibrary.ikeywords.ielement_async import iElementAsync
+from PuppeteerLibrary.utils.coverter import str2str
 
 
 class PlaywrightElement(iElementAsync):
@@ -21,7 +22,7 @@ class PlaywrightElement(iElementAsync):
         noWaitAfter = str2bool(noWaitAfter)
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
         await element.click(
-            noWaitAfter=noWaitAfter
+            no_wait_after=noWaitAfter
         )
 
     async def click_link(self, locator: str):
@@ -34,14 +35,17 @@ class PlaywrightElement(iElementAsync):
         await self._click_with_specific_tag(locator,'img')
 
     async def _click_with_specific_tag(self, locator: str, expect_tag_name: str):
+        expect_tag_name = str2str(expect_tag_name)
         elements = await self.library_ctx.get_current_page().querySelectorAll_with_selenium_locator(locator)
         for element in elements:
-            tag_name = await (await element.getProperty('tagName')).jsonValue()
+            tag_name = await (await element.get_property('tagName')).json_value()
             if tag_name.lower() == expect_tag_name:
                 return await element.click()
         raise Exception('Can\'t find the specific '+ expect_tag_name +' element for '+locator)
 
     async def click_element_at_coordinate(self, locator: str, xoffset: str, yoffset: str):
+        xoffset = str2str(xoffset)
+        yoffset = str2str(yoffset)
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
         await element.click(
             position={
@@ -50,8 +54,9 @@ class PlaywrightElement(iElementAsync):
             })
 
     async def upload_file(self, locator: str, file_path: str):
+        file_path = str2str(file_path)
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
-        await element.setInputFiles(file_path)
+        await element.set_input_files(file_path)
 
     async def press_keys(self, locator: str, *keys: str):
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
@@ -63,14 +68,14 @@ class PlaywrightElement(iElementAsync):
     ##############################
     async def element_should_be_enabled(self, locator: str):
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
-        is_disabled = await (await element.getProperty('disabled')).jsonValue()
+        is_disabled = await (await element.get_property('disabled')).json_value()
         if is_disabled:
             raise AssertionError("Element '%s' is disabled. " % locator)
         return element
 
     async def element_should_be_disabled(self, locator: str):
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
-        is_disabled = await (await element.getProperty('disabled')).jsonValue()
+        is_disabled = await (await element.get_property('disabled')).json_value()
         if not is_disabled:
             raise AssertionError("Element '%s' is enabled. " % locator)
         return element
@@ -91,26 +96,35 @@ class PlaywrightElement(iElementAsync):
     # Property
     ##############################
     async def element_should_contain(self, locator: str, expected: str, ignore_case=False):
+        expected = str2str(expected)
+        ignore_case = str2bool(ignore_case)
         text = await self.get_text(locator)
         return BuiltIn().should_contain(text, expected, ignore_case=ignore_case)
 
     async def element_should_not_contain(self, locator: str, expected: str, ignore_case=False):
+        expected = str2str(expected)
+        ignore_case = str2bool(ignore_case)
         text = await self.get_text(locator)
         return BuiltIn().should_not_contain(text, expected, ignore_case=ignore_case)
 
     async def get_text(self, locator: str):
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
-        return (await (await element.getProperty('textContent')).jsonValue())
+        return (await (await element.get_property('innerText')).json_value())
 
     async def get_attribute(self, locator: str, attribute: str) -> str:
+        attribute = str2str(attribute)
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)
-        return (await (await element.getProperty(attribute)).jsonValue())
+        return (await (await element.get_property(attribute)).json_value())
         
     async def element_text_should_be(self, locator: str, expected: str, ignore_case=False):
+        expected = str2str(expected)
+        ignore_case = str2bool(ignore_case)
         text = await self.get_text(locator)
         return BuiltIn().should_be_equal_as_strings(text, expected, ignore_case=ignore_case)
 
     async def element_text_should_not_be(self, locator: str, expected: str, ignore_case=False):
+        expected = str2str(expected)
+        ignore_case = str2bool(ignore_case)
         text = await self.get_text(locator)
         return BuiltIn().should_not_be_equal_as_strings(text, expected, ignore_case=ignore_case)
 
@@ -119,4 +133,4 @@ class PlaywrightElement(iElementAsync):
     ##############################
     async def scroll_element_into_view(self, locator: str):
         element = await self.library_ctx.get_current_page().querySelector_with_selenium_locator(locator)        
-        await element.scrollIntoViewIfNeeded()
+        await element.scroll_into_view_if_needed()
