@@ -1,4 +1,5 @@
 from PuppeteerLibrary.ikeywords.ijavascript_async import iJavascriptAsync
+from PuppeteerLibrary.utils.coverter import str2str
 
 
 class PlaywrightJavascript(iJavascriptAsync):
@@ -7,4 +8,5 @@ class PlaywrightJavascript(iJavascriptAsync):
         super().__init__(library_ctx)
 
     async def execute_javascript(self, code):
+        code = str2str(code)
         return await self.library_ctx.get_current_page().get_page().evaluate(code)
