@@ -8,8 +8,6 @@ class PlaywrightPDF(iPDFAsync):
 
     async def print_as_pdf(self, filename=DEFAULT_FILENAME_PAGE):
         path = self._get_pdf_path(filename)
-        await self.library_ctx.get_current_page().get_page().emulateMedia('screen')
-        await self.library_ctx.get_current_page().get_page().pdf(
-            path=path
-        )
+        await self.library_ctx.get_current_page().get_page().emulate_media()
+        await self.library_ctx.get_current_page().get_page().pdf(path=path)
         self.info('Print as pdf: '+path)
