@@ -1,3 +1,4 @@
+from PuppeteerLibrary.utils.coverter import str2bool, str2str
 from PuppeteerLibrary.playwright.async_keywords.playwright_waiting import PlaywrightWaiting
 from PuppeteerLibrary.ikeywords.iscreenshot_async import iScreenshotAsync
 
@@ -8,7 +9,9 @@ class PlaywrightScreenshot(iScreenshotAsync):
         super().__init__(library_ctx)
 
     async def capture_page_screenshot(self, path: str, fullPage: bool):
+        path = str2str(path)
+        fullPage = str2bool(fullPage)
         return await self.library_ctx.get_current_page().get_page().screenshot(
             path=f''+path,
-            fullPage=fullPage
+            full_page=fullPage
         )
