@@ -1,3 +1,4 @@
+from PuppeteerLibrary.utils.coverter import str2str
 import asyncio
 from PuppeteerLibrary.ikeywords.ialert_async import iAlertAsync
 
@@ -8,9 +9,13 @@ class PuppeteerAlert(iAlertAsync):
         super().__init__(library_ctx)
 
     async def handle_alert(self, action, prompt_text=''):
+        action = str2str(action)
+        prompt_text = str2str(prompt_text)
         return self.library_ctx.get_current_page().get_page().on('dialog', lambda dialog: asyncio.ensure_future(self.handle_dialog(dialog, action, prompt_text)))
 
     async def handle_dialog(self, dialog, action, prompt_text=''):
+        action = str2str(action)
+        prompt_text = str2str(prompt_text)
         if action == 'ACCEPT':
             await dialog.accept(prompt_text)
         elif action == 'DISMISS':
