@@ -1,3 +1,4 @@
+from PuppeteerLibrary.utils.coverter import str2bool, str2str
 from PuppeteerLibrary.ikeywords.iscreenshot_async import iScreenshotAsync
 
 
@@ -7,6 +8,8 @@ class PuppeteerScreenshot(iScreenshotAsync):
         super().__init__(library_ctx)
 
     async def capture_page_screenshot(self, path: str, fullPage: bool):
+        path = str2str(path)
+        fullPage = str2bool(fullPage)
         return await self.library_ctx.get_current_page().get_page().screenshot(
             {
                 'path': path,
